@@ -518,7 +518,10 @@ class DescribeMachineUnderwriteResponse(AbstractModel):
         :type MainTaskId: str
         :param UnderwriteTaskId: 核保任务ID
         :type UnderwriteTaskId: str
-        :param Status: 状态码
+        :param Status: 结果状态：
+0：返回成功
+1：结果未生成
+2：结果生成失败
         :type Status: int
         :param UnderwriteResults: 机器核保结果
         :type UnderwriteResults: list of MachineUnderwriteOutput
@@ -558,7 +561,9 @@ class DescribeReportClassifyRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param ServiceType: 服务类型（Structured/Underwrite）
+        :param ServiceType: 服务类型
+Structured 仅结构化
+Underwrite 结构化+核保
         :type ServiceType: str
         :param FileList: 文件地址数组
         :type FileList: list of str
@@ -937,7 +942,10 @@ class DescribeUnderwriteTaskResponse(AbstractModel):
         :type MainTaskId: str
         :param UnderwriteTaskId: 核保任务ID
         :type UnderwriteTaskId: str
-        :param Status: 状态码
+        :param Status: 结果状态：
+0：返回成功
+1：结果未生成
+2：结果生成失败
         :type Status: int
         :param UnderwriteResults: 核保结果
         :type UnderwriteResults: list of UnderwriteOutput
